@@ -6,7 +6,7 @@ def get_default_opts():
     default_opts = {
         'debug': True,  # Will enable advanced tests and outputs
         'coord_cam': 0,  # Reference camera that defines the multicam coordinate system
-        'frame_skip': 0,  # Skip frames in recording
+        'frame_step': 1,  # Skip frames in recording
         'allow_unequal_n_frame': False,  # Sometimes last frame is cut, so this may be okay.
         'common_pose_r_err': 0.1,  # Iteratively exclude poses with higher rotation deviation from mean
         'color_convert': False,  # Set to cv2.COLOR_RGB2GRAY to convert rgb images to grayscale for corner detection
